pub enum ExecutionKind {
Full,
Blocked,
Error,
}Expand description
How an explored execution terminated.
Full- nothing more can be added and every thread finished.Blocked- nothing more can be added but some thread is stuck on a blocking receive that never got a message (a maximal consistent prefix).Error- anerrorevent was reached.
Variants